/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.util.stax.dialect;

import javax.xml.stream.XMLStreamReader;

import org.apache.axiom.ext.stax.DTDReader;
import org.apache.axiom.ext.stax.DelegatingXMLStreamReader;
import org.apache.axiom.util.stax.wrapper.XMLStreamReaderWrapper;

class XLXPStreamReaderWrapper extends XMLStreamReaderWrapper implements DelegatingXMLStreamReader {
    public XLXPStreamReaderWrapper(XMLStreamReader parent) {
        super(parent);
    }

    @Override
    public Object getProperty(String name) {
        if (DTDReader.PROPERTY.equals(name)) {
            return new AbstractDTDReader(getParent()) {
                @Override
                protected String getDocumentTypeDeclaration(XMLStreamReader reader) {
                    return (String)reader.getProperty("javax.xml.stream.dtd.declaration");
                }
            };
        } else {
            return super.getProperty(name);
        }
    }

    public boolean isCharacters() {
        // XLXP returns true for SPACE events as well; this is not correct
        return getEventType() == CHARACTERS;
    }

    public XMLStreamReader getParent() {
        return super.getParent();
    }
}
