/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.om.factory;

import org.apache.axiom.om.OMContainer;
import org.apache.axiom.om.OMFactory;

public abstract class CreateOMElementParentSupplier {
    public static final CreateOMElementParentSupplier[] INSTANCES = {
        new CreateOMElementParentSupplier("null") {
            public boolean isSupported(CreateOMElementVariant variant) {
                return true;
            }

            public OMContainer createParent(OMFactory factory) {
                return null;
            }
        },
        new CreateOMElementParentSupplier("document") {
            public boolean isSupported(CreateOMElementVariant variant) {
                return variant.isSupportsContainer();
            }

            public OMContainer createParent(OMFactory factory) {
                return factory.createOMDocument();
            }
        },
        new CreateOMElementParentSupplier("element") {
            public boolean isSupported(CreateOMElementVariant variant) {
                return variant.isSupportsContainer();
            }

            public OMContainer createParent(OMFactory factory) {
                return factory.createOMElement("test", null);
            }
        },
    };

    private final String name;
    
    public CreateOMElementParentSupplier(String name) {
        this.name = name;
    }
    
    public final String getName() {
        return name;
    }

    public abstract boolean isSupported(CreateOMElementVariant variant);
    public abstract OMContainer createParent(OMFactory factory);
}
